@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK  -  Tilburg University
   CNTS -  University of Antwerp
  
@@ -29,7 +29,7 @@
 #include <cstdio>
 #include <signal.h>
 #include <iostream>
-#include "timbl/Types.h"
+#include "ticcutils/StringOps.h"
 #include "timblserver/SocketBasics.h"
 
 using namespace std;
@@ -170,7 +170,7 @@ int main( int argc, const char *argv[] ){
   if ( argc > 2 )
     tos = argv[2];
   int timeOut;
-  if ( !Timbl::stringTo<int>( tos, timeOut ) ){
+  if ( !TiCC::stringTo<int>( tos, timeOut ) ){
     cerr << "invalid timeout" << endl;
     cerr << "usage: " << argv[0] << " <port> <timeout>" << endl;
     return 1;
