@@ -1,8 +1,8 @@
 /*
-  $Id: ClientBase.cxx 15086 2012-08-09 10:03:00Z sloot $
+  $Id: ClientBase.cxx 15829 2013-03-28 11:56:41Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/TimblServer/src/ClientBase.cxx $
 
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -32,6 +32,7 @@
 #include <cstdlib>
 #include <csignal>
 #include "timbl/TimblAPI.h"
+#include "ticcutils/StringOps.h"
 #include "timblserver/FdStream.h"
 #include "timblserver/ClientBase.h"
 
@@ -75,7 +76,7 @@ namespace TimblServer {
 	 << port << endl;
     string line;
     if ( client.connect( node, port) ){
-      serverPort = Timbl::stringTo<int>( port );
+      serverPort = TiCC::stringTo<int>( port );
       serverName = node;
       if ( client.read( line ) ){
 	//	cout << "read line " << line << endl;
