@@ -1,8 +1,8 @@
 /*
-  $Id: ServerBase.cxx 15059 2012-08-08 08:27:17Z sloot $
+  $Id: ServerBase.cxx 15874 2013-04-02 15:46:31Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/TimblServer/src/ServerBase.cxx $
 
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -40,6 +40,7 @@
 #include "config.h"
 #include "timblserver/FdStream.h"
 #include "timblserver/ServerBase.h"
+#include "ticcutils/Timer.h"
 
 using namespace std;
 using namespace TiCC;
@@ -536,7 +537,7 @@ namespace TimblServer {
   void ServerClass::RunClassicServer(){
     if ( !pidFile.empty() ){
       // check validity of pidfile
-      if ( pidFile[0] != '/' ) // make sure the path is absolute
+      if ( doDaemon && pidFile[0] != '/' ) // make sure the path is absolute
 	pidFile = '/' + pidFile;
       unlink( pidFile.c_str() ) ;
       ofstream pid_file( pidFile.c_str() ) ;
@@ -548,7 +549,7 @@ namespace TimblServer {
     }
     ostream *logS = 0;
     if ( !logFile.empty() ){
-      if ( logFile[0] != '/' ) // make sure the path is absolute
+      if ( doDaemon && logFile[0] != '/' ) // make sure the path is absolute
 	logFile = '/' + logFile;
       logS = new ofstream( logFile.c_str() );
       if ( logS && logS->good() ){
@@ -822,11 +823,11 @@ namespace TimblServer {
 		      while ( it != range.second ){
 			if ( it->second == "settings" ){
 			  xmlNode *tmp = api->settingsToXML();
-			  XmlAddChild( root, tmp );
+			  xmlAddChild( root, tmp );
 			}
 			else if ( it->second == "weights" ){
 			  xmlNode *tmp = api->weightsToXML();
-			  XmlAddChild( root, tmp );
+			  xmlAddChild( root, tmp );
 			}
 			else 
 			  LS << "don't know how to SHOW: " 
@@ -869,18 +870,18 @@ namespace TimblServer {
 			       << endl;
 			  
 			  xmlNode *cl = XmlNewChild( root, "classification" );
-			  XmlNewChild( cl, "input", params );
-			  XmlNewChild( cl, "category", answer );
+			  XmlNewTextChild( cl, "input", params );
+			  XmlNewTextChild( cl, "category", answer );
 			  if ( api->Verbosity(DISTRIB) ){
-			    XmlNewChild( cl, "distribution", distrib );
+			    XmlNewTextChild( cl, "distribution", distrib );
 			  }
 			  if ( api->Verbosity(DISTANCE) ){
-			    XmlNewChild( cl, "distance",
+			    XmlNewTextChild( cl, "distance",
 					 toString<double>(distance) );
 			  }
 			  if ( api->Verbosity(NEAR_N) ){
 			    xmlNode *nb = api->bestNeighborsToXML();
-			    XmlAddChild( cl, nb );
+			    xmlAddChild( cl, nb );
 			  }
 			}
 			else {
