@@ -1,8 +1,8 @@
 /*
-  $Id: TimblServer.cxx 15086 2012-08-09 10:03:00Z sloot $
+  $Id: TimblServer.cxx 15829 2013-03-28 11:56:41Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/TimblServer/src/TimblServer.cxx $
 
-  Copyright (c) 1998 - 2012
+  Copyright (c) 1998 - 2013
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
@@ -190,7 +190,7 @@ void Preset_Values( TimblOpts& Opts ){
     }
     else {
       Do_Server = true;
-      ServerPort = stringTo<int>( value );
+      ServerPort = TiCC::stringTo<int>( value );
       if ( ServerPort < 1 || ServerPort > 100000 ){
 	cerr << "-S option, portnumber invalid: " << ServerPort << endl;
 	throw( softExit() );
@@ -212,7 +212,7 @@ void Preset_Values( TimblOpts& Opts ){
       cerr << "-C option invalid without -S" << endl;
       throw( softExit() );
     }
-    Max_Connections = stringTo<int>( value );
+    Max_Connections = TiCC::stringTo<int>( value );
     if ( Max_Connections < 1 || Max_Connections > 1000 ){
       cerr << "-C options, max number of connection invalid: " 
 	   << Max_Connections << endl;
@@ -328,7 +328,7 @@ int main(int argc, char *argv[]){
     // Start.
     //
     cerr << "TiMBL Server " << TimblServer::Version()
-	 << " (c) ILK 1998 - 2012.\n" 
+	 << " (c) ILK 1998 - 2013.\n" 
 	 << "Tilburg Memory Based Learner\n"
 	 << "Induction of Linguistic Knowledge Research Group, Tilburg University\n"
 	 << "CLiPS Computational Linguistics Group, University of Antwerp\n" 
